@echo off

REM
REM * ============================================================================
REM * Licensed Materials - Property of IBM
REM * Project  Zero
REM *
REM * (C) Copyright IBM Corp. 2008  All Rights Reserved.
REM *
REM * US Government Users Restricted Rights - Use, duplication or disclosure
REM * restricted by GSA ADP Schedule Contract with IBM Corp.
REM * ============================================================================
REM

@setlocal

set INSTALLED=%ZERO_HOME%\installed
set AB_HOME=%INSTALLED%\appbuilder

if not exist "%AB_HOME%" goto create_ab
goto run_command

REM -----------------------------------------------------------------
REM Create the AppBuilder application.
REM -----------------------------------------------------------------

:create_ab

echo -------------------------------------------------------
echo Creating the AppBuilder application.
echo This step may take a while.
echo -------------------------------------------------------

REM Create the installed directory.
if not exist "%INSTALLED%" mkdir "%INSTALLED%"

REM Remove the bootstrap application just to be safe.
set BOOTSTRAP_HOME=%INSTALLED%\appbuilder.bootstrap
if exist "%BOOTSTRAP_HOME%" rmdir /S /Q "%BOOTSTRAP_HOME%"

REM Create the bootstrap application.
call "%ZERO_HOME%\zero" create "%BOOTSTRAP_HOME%"
if not %ERRORLEVEL% == 0 goto create_bootstrap_failed
cd /d "%BOOTSTRAP_HOME%"

REM Create the experimental modulegroup and switch to it.
:create_experimental
call "%ZERO_HOME%\zero" modulegroup create experimental
if not %ERRORLEVEL% == 0 goto create_experimental_failed
call "%ZERO_HOME%\zero" switch experimental
if not %ERRORLEVEL% == 0 goto switch_experimental_failed
goto do_create_ab

REM Create the AppBuilder.
:do_create_ab
call "%ZERO_HOME%\zero" create "%AB_HOME%" linkto zero:zero.appbuilder
if not %ERRORLEVEL% == 0 goto create_ab_failed
cd /d "%ZERO_HOME%"
rmdir /S /Q "%BOOTSTRAP_HOME%"
goto run_command

REM -----------------------------------------------------------------
REM Run the specified command.
REM -----------------------------------------------------------------

:run_command
set ZRP=%AB_HOME%\.zero\private\resolved.properties
set SCRIPT_HOME=
for /F "usebackq eol=; tokens=1,2* delims==" %%i in ("%ZRP%") do if %%i == zero.appbuilder.core ( set SCRIPT_HOME=%%j\.)
set SCRIPT_HOME=%SCRIPT_HOME:\:=:%
set SCRIPT_HOME=%SCRIPT_HOME:\\=\%
if exist "%SCRIPT_HOME%\appbuilder.bat" goto call_script
echo could not find zero.appbuilder.core\appbuilder.bat
set EXIT_CODE=1
goto end

:call_script
call "%SCRIPT_HOME%\appbuilder" %*
goto end

REM -----------------------------------------------------------------
REM Error handling
REM -----------------------------------------------------------------

:create_bootstrap_failed
echo ERROR: Failed to create bootstrap application at %BOOTSTRAP_HOME%
if exist "%BOOTSTRAP_HOME%" rmdir /S /Q "%BOOTSTRAP_HOME%"
goto end

:create_experimental_failed
echo ERROR: Failed to create the experimental modulegroup
if exist "%BOOTSTRAP_HOME%" rmdir /S /Q "%BOOTSTRAP_HOME%"
goto end

:switch_experimental_failed
echo ERROR: Failed to switch to the experimental modulegroup
if exist "%BOOTSTRAP_HOME%" rmdir /S /Q "%BOOTSTRAP_HOME%"
goto end

:create_ab_failed
echo ERROR: Failed to create the AppBuilder application at %AB_HOME%
if exist "%BOOTSTRAP_HOME%" rmdir /S /Q "%BOOTSTRAP_HOME%"
if exist "%AB_HOME%" rmdir /S /Q "%AB_HOME%"
goto end

REM -----------------------------------------------------------------
REM Done
REM -----------------------------------------------------------------

:end
@endlocal
